package
Version:
v0.0.0-...-2e5d29b
Opens a new window with list of versions in this module.
Published: Jan 12, 2016
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Ignore removes a correction rule
WARNING: multiple calls to this will unset the previous calls.
thats not so good.
Replace takes input string and does spelling corrections on
commonly misspelled words.
ReplaceDebug logs exactly what was matched and replaced for using
in debugging
ReplaceGo is a specialized routine for correcting Golang source
files. Currently only checks comments, not identifiers for
spelling.
Other items:
- check strings, but need to ignore
- import "statements" blocks
- import ( "blocks" )
- skip first comment (line 0) if build comment
Diff is datastructure showing what changed in a single line
func DiffLines(filename, input, output string) []Diff
DiffLines produces a grep-like diff between two strings showing
filename, linenum and change. It is not meant to be a comprehensive diff.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.